/**
 * XMLHttpRequest is a JavaScript object that was designed by Microsoft and adopted by Mozilla, Apple, and Google. It's now being standardized in the W3C. It provides an easy way to retrieve data at a URL. Despite its name, XMLHttpRequest can be used to retrieve any type of data, not just XML, and it supports protocols other than HTTP (including file and ftp).
 * @syntax var req = new XMLHttpRequest();
 */
function XMLHttpRequest() {
}
/**
 * Indicates whether or not cross-site Access-Control requests should be made using credentials such as cookies or authorization headers. The default is false.
 * @returns {Boolean} 
 */
XMLHttpRequest.prototype.withCredentials = new Boolean();

/**
 * Returns all the response headers as a string, or null if no response has been received. Note: For multipart requests, this returns the headers from the current part of the request, not from the original channel.
 * @syntax xmlHttpRequest.getAllResponseHeaders()
 * @returns {String} 
 */
XMLHttpRequest.prototype.getAllResponseHeaders = function() {};

/**
 * Sends the request. If the request is asynchronous (which is the default), this method returns as soon as the request is sent. If the request is synchronous, this method doesn't return until the response has arrived.
 * @syntax xmlHttpRequest.send(string)
 * @param {String} string Sends the request off to the server.
 * @returns {undefined} 
 */
XMLHttpRequest.prototype.send = function(string) {};

/**
 * A JavaScript function object that is called whenever the readyState attribute changes. The callback is called from the user interface thread.
 * @returns {Function} 
 */
XMLHttpRequest.prototype.onreadystatechange = new Function();

/**
 * The status of the response to the request. This is the HTTP result code (for example, status is 200 for a successful request). Read-only.
 * @returns {Number} 
 */
XMLHttpRequest.prototype.status = new Number();

/**
 * The response to the request as a DOM Document object, or null if the request was unsuccessful, has not yet been sent, or cannot be parsed as XML or HTML. The response is parsed as if it were a text/xml stream. When the responseType is set to "document" and the request has been made asynchronously, the response is parsed as it were a text/html stream . Read-only.
 * @returns {Document} 
 */
XMLHttpRequest.prototype.responseXML = new Document();

/**
 * The response string returned by the HTTP server. Unlike status, this includes the entire text of the response message ("200 OK", for example). Read-only.
 * @returns {String} 
 */
XMLHttpRequest.prototype.statusText = new String();

/**
 * The state of the request.
 * @returns {Number} 
 */
XMLHttpRequest.prototype.readyState = new Number();

/**
 * The response to the request as text, or null if the request was unsuccessful or has not yet been sent. Read-only.
 * @returns {String} 
 */
XMLHttpRequest.prototype.responseText = new String();

/**
 * Overrides the MIME type returned by the server. This may be used, for example, to force a stream to be treated and parsed as text/xml, even if the server does not report it as such.This method must be called before send().
 * @syntax xmlHttpRequest.overrideMimeType()
 * @param {String} mimetype 
 * @returns {undefined} 
 */
XMLHttpRequest.prototype.overrideMimeType = function() {};

/**
 * The upload process can be tracked by adding an event listener to upload.
 * @returns {XMLHttpRequestUpload} 
 */
XMLHttpRequest.prototype.upload = new XMLHttpRequestUpload();

/**
 * The response entity body according to responseType, as an ArrayBuffer, Blob, Document , JavaScript object (for "json"), or string. This is null if the request is not complete or was not successful.
 * @returns {undefined} 
 */
XMLHttpRequest.prototype.response;

/**
 * Initializes a request. This method is to be used from JavaScript code; to initialize a request from native code, use openRequest()instead.
 * @syntax xmlHttpRequest.open(method,url,async,uname,pswd)
 * @param {String} method The HTTP method to use, such as "GET", "POST", "PUT", "DELETE", etc. Ignored for non-HTTP(S) URLs.
 * @param {String} url The URL to which to send the request.
 * @param {Boolean} async An optional boolean parameter, defaulting to true, indicating whether or not to perform the operation asynchronously. If this value is false, the send()method does not return until the response is received. If true, notification of a completed transaction is provided using event listeners. This must be true if the multipart attribute is true, or an exception will be thrown.
 * @param {String} user The optional user name to use for authentication purposes; by default, this is an empty string.
 * @param {String} password The optional password to use for authentication purposes; by default, this is an empty string.
 * @returns {undefined} 
 */
XMLHttpRequest.prototype.open = function(method, url, async, uname, pswd) {};

/**
 * Returns the string containing the text of the specified header, or null if either the response has not yet been received or the header doesn't exist in the response.
 * @syntax xmlHttpRequest.getResponseHeader()
 * @param {String} header 
 * @returns {String} 
 */
XMLHttpRequest.prototype.getResponseHeader = function() {};

/**
 * Sets the value of an HTTP request header.You must call setRequestHeader() after open(), but before send().
 * @syntax xmlHttpRequest.setRequestHeader()
 * @param {String} header The name of the header whose value is to be set.
 * @param {String} value The value to set as the body of the header.
 * @returns {undefined} 
 */
XMLHttpRequest.prototype.setRequestHeader = function() {};

/**
 * Can be set to change the response type. This tells the server what format you want the response to be in.
 * @returns {XMLHttpRequestResponseType} 
 */
XMLHttpRequest.prototype.responseType = new XMLHttpRequestResponseType();

/**
 * The number of milliseconds a request can take before automatically being terminated. A value of 0 (which is the default) means there is no timeout.
 * @returns {Number} 
 */
XMLHttpRequest.prototype.timeout = new Number();

/**
 * Aborts the request if it has already been sent.
 * @syntax xmlHttpRequest.abort()
 * @returns {undefined} 
 */
XMLHttpRequest.prototype.abort = function() {};

/**
 * Represents the XMLHttpRequest prototype object.
 * @syntax XMLHttpRequest.prototype
 * @static
 */
XMLHttpRequest.prototype;

